# Generated by Django 4.1.3 on 2023-07-07 07:34

from django.db import migrations, models
import django.db.models.deletion


from django.conf import settings
DYNAMIC_FILE_UPLOADED_BY_MODEL = settings.DYNAMIC_FILE_UPLOADED_BY_MODEL


class Migration(migrations.Migration):

    dependencies = [
        ('dynamic_file', '0002_alter_dynamicfile_file'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dynamicfile',
            name='uploaded_by',
            field=models.ForeignKey(blank=True, help_text='The owner/uploader of this file', null=True,
                                    on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=DYNAMIC_FILE_UPLOADED_BY_MODEL),
        ),
        migrations.AddField(
            model_name='dynamicfile',
            name='display_name',
            field=models.CharField(blank=True, default='',
                                   help_text='An optional displayable name for this file.', max_length=128),
        ),
    ]
