# Generated by Django 4.1.3 on 2023-05-22 16:21

from django.db import migrations, models
import dynamic_file.storage


class Migration(migrations.Migration):

    dependencies = [
        ('dynamic_file', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dynamicfile',
            name='file',
            field=models.FileField(help_text='The uploaded file', storage=dynamic_file.storage.DynamicFileSystemStorage(), upload_to=''),
        ),
    ]
