# Generated by Django 4.1.3 on 2023-07-07 11:35

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('dynamic_file', '0003_alter_dynamicfile_uploaded_by'),
    ]

    operations = [
        migrations.AddField(
            model_name='dynamicfile',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, help_text='The creation date of this file'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='dynamicfile',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, help_text='The last update date of this file'),
        ),
    ]
